/*
  getcalpars - read in a stereo calibration data from a file
  
  bristol 11/98

*/
#include <math.h>
#include <stdio.h>
#include "iplib.h"

void getcalpars(char *filename,CalPars *data)
{
    FILE *fp;
    
    fprintf(stderr,"getcalpars: opening %s\n",filename);
    
    fp=fopen(filename,"r");
    if(!fp) {
	fprintf(stderr,"getcalpars: error opening file\n");
	exit(0);
    }
    
    if(fscanf(fp,"R={{%f,%f,%f},{%f,%f,%f},{%f,%f,%f}}\n",&(data->R[0][0]),&(data->R[0][1]),&(data->R[0][2]),&(data->R[1][0]),&(data->R[1][1]),&(data->R[1][2]),&(data->R[2][0]),&(data->R[2][1]),&(data->R[2][2]))!=9) {
	fprintf(stderr,"getcalpars: error reading rotation matrix\n");
	exit(0);
    }
    if(fscanf(fp,"T={%f,%f,%f}\n",&(data->T[0]),&(data->T[1]),&(data->T[2]))!=3) {
	fprintf(stderr,"getcalpars: error reading translation vector\n");
	exit(0);
    }
    if(fscanf(fp,"fL=%f\n",&(data->leftcam.f))!=1) {
	fprintf(stderr,"getcalpars: error reading left focal length\n");
	exit(0);
    }
    if(fscanf(fp,"sL=%f,%f\n",&(data->leftcam.sx),&(data->leftcam.sy))!=2) {
	fprintf(stderr,"getcalpars: error reading left pixel size\n");
	exit(0);
    }
    if(fscanf(fp,"cL=%f,%f\n",&(data->leftcam.ox),&(data->leftcam.oy))!=2) {
	fprintf(stderr,"getcalpars: error reading left image centre\n");
	exit(0);
    }
    if(fscanf(fp,"fR=%f\n",&(data->rightcam.f))!=1) {
	fprintf(stderr,"getcalpars: error reading right focal length\n");
	exit(0);
    }
    if(fscanf(fp,"sR=%f,%f\n",&(data->rightcam.sx),&(data->rightcam.sy))!=2) {
	fprintf(stderr,"getcalpars: error reading right pixel size\n");
	exit(0);
    }
    if(fscanf(fp,"cR=%f,%f\n",&(data->rightcam.ox),&(data->rightcam.oy))!=2) {
	fprintf(stderr,"getcalpars: error reading right image centre\n");
	exit(0);
    }
    data->leftcam.sx=1.0/data->leftcam.sx;
    data->leftcam.sy=1.0/data->leftcam.sy;
    data->rightcam.sx=1.0/data->rightcam.sx;
    data->rightcam.sy=1.0/data->rightcam.sy;

    fclose(fp);

}
	
